// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Code in this file should be able to be imported by both dart:html and
// dart:io dependent libraries.

import 'package:flutter/foundation.dart';

/// Base class for all screen metrics classes.
///
/// Create a subclass of this class to store custom metrics for a screen. All
/// subclasses are expected to add custom metrics as fields. For example:
///
/// ```dart
/// class MyScreenAnalyticsMetrics extends ScreenAnalyticsMetrics {
///   const MyScreenAnalyticsMetrics({this.myMetric1, this.myMetric2});
///
///   final int myMetric1;
///
///   final String myMetric2;
/// }
/// ```
///
/// Then, add your fields to the `GtagEventDevTools.withScreenMetrics` factory
/// constructor.
abstract class ScreenAnalyticsMetrics {}

@protected
abstract class AnalyticsControllerBase {
  final ValueListenable<bool> analyticsEnabled = ValueNotifier<bool>(false);
  final ValueListenable<bool> shouldPrompt = ValueNotifier<bool>(false);
  bool get analyticsInitialized => false;
  Future<void> toggleAnalyticsEnabled(bool enable) async {}
  void setUpAnalytics() {}
  void hidePrompt() {}
}
